<?php

namespace XenGenTr\XGTStyleV5\Widget;

use XF\Widget\AbstractWidget;

class LiderKonular  extends AbstractWidget
{

	public function render()
	{
		$visitor = \XF::visitor();

		$options = $this->options;
		$limit = 5;
		$nodeIds = $options['node_ids'];


		/** @var \XF\Finder\Thread $threadFinder */
		$threadFinder = $this->finder('XF:Thread');
		$threadFinder
		    ->with(['Forum', 'User'])
			->with('Forum.Node.Permissions|' . $visitor->permission_combination_id)
			->where('discussion_state', 'visible')
			->where('discussion_type', '<>', 'redirect')
			->where('first_post_reaction_score', '>', 0)
			->order('first_post_reaction_score', 'DESC')
			->limit(max($limit * 2, 10));

		    switch ($timeLapse)
		    {
			    default:

			    case 'alltime':
					$title = \XF::phrase('ml_most_liked_threads_all_time');
				break;
				
				case 'custom':
					$date = new \DateTime();
					$now = $date->getTimestamp();
					$optionsDays = $custom_time_frame_days * 86400;
					$days = $now - $optionsDays;
					$threadFinder->where('post_date', '>=', $days);
					$title = \XF::phrase('ml_most_liked_threads_last_x_days', ['days' => $custom_time_frame_days]);
				break;
		    }
				 
		/** @var \XF\Entity\Thread $thread */
		foreach ($threads = $threadFinder->fetch() AS $threadId => $thread)
		{
			if(!$visitor->user_id && $style != 'expanded')
			{
				$nodeId = $thread->Forum->node_id;
				$canview = ($visitor->hasNodePermission($nodeId, 'view') 
				&& $visitor->hasNodePermission($nodeId, 'viewOthers') 
				&& $thread->discussion_state == 'visible');
			}
			else
			{
				$canview = $thread->canView();
			}

			if (!$canview
				|| $visitor->isIgnoring($thread->user_id)
			)
			{
				unset($threads[$threadId]);
			}

			if ($style != 'expanded' && $visitor->isIgnoring($thread->last_post_user_id))
			{
				unset($threads[$threadId]);
			}
		}
		
		$total = $threads->count();
		$threads = $threads->slice(0, $limit, true);

		$viewParams = [
			'title' => $this->getTitle() ?: $title,
			'link' => $link,
			'threads' => $threads,
			'style' => $options['style'],
		];
		return $this->renderer('XGTSv5_tepkilideri_konular', $viewParams);
	}

	public function verifyOptions(\XF\Http\Request $request, array &$options, &$error = null)
	{
		$options = $request->filter([
			'limit' => 'uint',
			'style' => 'str',
		]);
		
		if ($options['limit'] < 1)
		{
			$options['limit'] = 1;
		}
		
		if ($options['style'] != 'expanded')
		{
			$options['show_expanded_title'] = false;
		}
		
		if ($options['style'] != 'simple')
		{
			$options['minimal'] = false;
		}
		
		if ($options['style'] == 'full' || $options['style'] == 'simple')
		{
		    $options['limit_char'] = 0;
		}
		
		return true;
	}
}